## WLogger
Class to generate system logs.
You can create instances or use a general one
```
from WLogger import loggen

loggen.info('test logger')
```
Like instance
```
from WLogger import Logger

log = Logger()
log.info('test logger from new class')
```